==> roundcube_1.6.5+dfsg.orig-tinymce.tar.xz: tinymce/modules/bridge/src/main/ts/ephox/bridge/api/Menu.ts <==
import { CardContainer, CardContainerSpec } from '../components/menu/card/CardContainer';
import { CardImage, CardImageSpec } from '../components/menu/card/CardImage';
import { CardItem, CardItemSpec } from '../components/menu/card/CardItem';
import { CardText, CardTextSpec } from '../components/menu/card/CardText';
import { CardMenuItem, CardMenuItemInstanceApi, CardMenuItemSpec, createCardMenuItem } from '../components/menu/CardMenuItem';
import { ChoiceMenuItem, ChoiceMenuItemInstanceApi, ChoiceMenuItemSpec, createChoiceMenuItem } from '../components/menu/ChoiceMenuItem';
import { ContextMenuApi, ContextMenuContents, ContextMenuItem, ContextSubMenu } from '../components/menu/ContextMenu';
import { createFancyMenuItem, FancyActionArgsMap, FancyMenuItem, FancyMenuItemSpec } from '../components/menu/FancyMenuItem';
import { createMenuItem, MenuItem, MenuItemInstanceApi, MenuItemSpec } from '../components/menu/MenuItem';
import {
  createNestedMenuItem, NestedMenuItem, NestedMenuItemContents, NestedMenuItemInstanceApi, NestedMenuItemSpec
} from '../components/menu/NestedMenuItem';
import { createSeparatorMenuItem, SeparatorMenuItem, SeparatorMenuItemSpec } from '../components/menu/SeparatorMenuItem';
import { createToggleMenuItem, ToggleMenuItem, ToggleMenuItemInstanceApi, ToggleMenuItemSpec } from '../components/menu/ToggleMenuItem';

export {
  createMenuItem,
  MenuItem,
  MenuItemSpec,
  MenuItemInstanceApi,

  createNestedMenuItem,
  NestedMenuItemContents,
  NestedMenuItem,
  NestedMenuItemSpec,
  NestedMenuItemInstanceApi,

  createFancyMenuItem,
  FancyMenuItem,
  FancyMenuItemSpec,
  FancyActionArgsMap,

  createToggleMenuItem,
  ToggleMenuItem,
  ToggleMenuItemSpec,
  ToggleMenuItemInstanceApi,

  createChoiceMenuItem,
  ChoiceMenuItem,
  ChoiceMenuItemSpec,
  ChoiceMenuItemInstanceApi,

  createSeparatorMenuItem,
  SeparatorMenuItem,
  SeparatorMenuItemSpec,

  ContextMenuApi,
  ContextMenuContents,
  ContextMenuItem,
  ContextSubMenu,

  createCardMenuItem,
  CardMenuItem,
  CardMenuItemSpec,
  CardMenuItemInstanceApi,

  CardItemSpec,
  CardItem,

  CardContainerSpec,
  CardContainer,
  CardImageSpec,
  CardImage,
  CardTextSpec,
  CardText
};

==> roundcube_1.6.12+dfsg.orig-tinymce.tar.xz: tinymce/modules/bridge/src/main/ts/ephox/bridge/api/Menu.ts <==
import { CardContainer, CardContainerSpec } from '../components/menu/card/CardContainer';
import { CardImage, CardImageSpec } from '../components/menu/card/CardImage';
import { CardItem, CardItemSpec } from '../components/menu/card/CardItem';
import { CardText, CardTextSpec } from '../components/menu/card/CardText';
import { CardMenuItem, CardMenuItemInstanceApi, CardMenuItemSpec, createCardMenuItem } from '../components/menu/CardMenuItem';
import { ChoiceMenuItem, ChoiceMenuItemInstanceApi, ChoiceMenuItemSpec, createChoiceMenuItem } from '../components/menu/ChoiceMenuItem';
import { ContextMenuApi, ContextMenuContents, ContextMenuItem, ContextSubMenu } from '../components/menu/ContextMenu';
import {
  createFancyMenuItem, ColorSwatchMenuItem, ColorSwatchMenuItemSpec, FancyActionArgsMap, FancyMenuItem, FancyMenuItemSpec, InsertTableMenuItem,
  InsertTableMenuItemSpec
} from '../components/menu/FancyMenuItem';
import { createMenuItem, MenuItem, MenuItemInstanceApi, MenuItemSpec } from '../components/menu/MenuItem';
import {
  createNestedMenuItem, NestedMenuItem, NestedMenuItemContents, NestedMenuItemInstanceApi, NestedMenuItemSpec
} from '../components/menu/NestedMenuItem';
import { createSeparatorMenuItem, SeparatorMenuItem, SeparatorMenuItemSpec } from '../components/menu/SeparatorMenuItem';
import { createToggleMenuItem, ToggleMenuItem, ToggleMenuItemInstanceApi, ToggleMenuItemSpec } from '../components/menu/ToggleMenuItem';

export {
  createMenuItem,
  MenuItem,
  MenuItemSpec,
  MenuItemInstanceApi,

  createNestedMenuItem,
  NestedMenuItemContents,
  NestedMenuItem,
  NestedMenuItemSpec,
  NestedMenuItemInstanceApi,

  createFancyMenuItem,
  FancyMenuItem,
  FancyMenuItemSpec,
  FancyActionArgsMap,
  ColorSwatchMenuItem,
  ColorSwatchMenuItemSpec,
  InsertTableMenuItem,
  InsertTableMenuItemSpec,

  createToggleMenuItem,
  ToggleMenuItem,
  ToggleMenuItemSpec,
  ToggleMenuItemInstanceApi,

  createChoiceMenuItem,
  ChoiceMenuItem,
  ChoiceMenuItemSpec,
  ChoiceMenuItemInstanceApi,

  createSeparatorMenuItem,
  SeparatorMenuItem,
  SeparatorMenuItemSpec,

  ContextMenuApi,
  ContextMenuContents,
  ContextMenuItem,
  ContextSubMenu,

  createCardMenuItem,
  CardMenuItem,
  CardMenuItemSpec,
  CardMenuItemInstanceApi,

  CardItemSpec,
  CardItem,

  CardContainerSpec,
  CardContainer,
  CardImageSpec,
  CardImage,
  CardTextSpec,
  CardText
};
